
/*
 * de.unkrig.commons - A general-purpose Java class library
 *
 * Copyright (c) 2012, Arno Unkrig
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *    1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
 *       following disclaimer.
 *    2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *       following disclaimer in the documentation and/or other materials provided with the distribution.
 *    3. The name of the author may not be used to endorse or promote products derived from this software without
 *       specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.unkrig.commons.file.zipentrytransformation;

import java.io.IOException;
import java.io.InputStream;
import java.util.zip.ZipEntry;
import java.util.zip.ZipOutputStream;

/**
 * When a ZIP format file is transformed, this interface is called as follows:
 * <ol>
 *   <li>
 *     For each entry of the ZIP format file, {@link #visitEntry(String, ZipEntry, InputStream, ZipEntryTransformer,
 *     ZipOutputStream)} is invoked. {@link #visitEntry(String, ZipEntry, InputStream, ZipEntryTransformer,
 *     ZipOutputStream)} typically creates and fills one (or more) entries on the {@link ZipOutputStream}.
 *   </li>
 *   <li>
 *     After the last entry, {@link #visitEnd(String, ZipOutputStream)} is invoked, which could add more entries on the
 *     {@link ZipOutputStream}.
 *   </li>
 * </ol>
 *
 * @see de.unkrig.commons.file.filetransformation.FileTransformationUtil#newZipFileTransformer(boolean,
 *      de.unkrig.commons.lang.protocol.Predicate, de.unkrig.commons.text.pattern.Glob, ZipEntriesTransformer, boolean,
 *      de.unkrig.commons.file.contentstransformation.ContentsTransformer, de.unkrig.commons.file.ExceptionHandler)
 */
public
interface ZipEntriesTransformer {

    /**
     * @param prefix Characterizes the file being processed, e.g. "dir/file.zip!"
     */
    void
    visitEntry(
        String              prefix,
        ZipEntry            entry,
        InputStream         is,
        ZipEntryTransformer zipEntryTransformer,
        ZipOutputStream     out
    ) throws IOException;

    /**
     * @param prefix Characterizes the file being processed, e.g. "dir/file.zip!"
     */
    void
    visitEnd(String prefix, ZipOutputStream out) throws IOException;
}
